s/PRODUCT-SERVICES/PRODUCT_SERVICES/g

Attempting to reduce the number of different spellings we have for
"product-services" in the codebase.

Bug: 112431447
Test: m
Change-Id: Iec531122297cf4b86ff8601732d4ab7ccf5c2183
diff --git a/tools/releasetools/add_img_to_target_files.py b/tools/releasetools/add_img_to_target_files.py
index 932fab9..66fe18b 100755
--- a/tools/releasetools/add_img_to_target_files.py
+++ b/tools/releasetools/add_img_to_target_files.py
@@ -200,7 +200,7 @@
 
 
 def AddProductServices(output_zip):
   """Turn the contents of PRODUCT-SERVICES into a product-services image and
   store it in output_zip."""
 
   img = OutputFile(output_zip, OPTIONS.input_tmp, "IMAGES",
@@ -664,7 +664,7 @@
                  os.path.exists(os.path.join(OPTIONS.input_tmp, "IMAGES",
                                              "product.img")))
   has_product_services = (os.path.isdir(os.path.join(OPTIONS.input_tmp,
-                                                     "PRODUCT-SERVICES")) or
+                                                     "PRODUCT_SERVICES")) or
                           os.path.exists(os.path.join(OPTIONS.input_tmp,
                                                       "IMAGES",
                                                       "product-services.img")))
@@ -200,7 +200,7 @@
 
 def AddProductServices(output_zip):
-  """Turn the contents of PRODUCT-SERVICES into a product-services image and
+  """Turn the contents of PRODUCT_SERVICES into a product-services image and
   store it in output_zip."""
 